require_relative "../test_helper"

class EmptyExampleTest < MTest
end
